@@ -40,7 +40,7 @@
  */
 
 #define _GNU_SOURCE
-#define _SVID_SOURCE /* for putenv() and some signal-related functions */
+#define _XOPEN_SOURCE /* for putenv() and some signal-related functions */
 
 #include <config.h>
 #include "main.h"
@@ -87,26 +87,6 @@ static gboolean meta_restart_after_quit = FALSE;
 static void prefs_changed_callback (MetaPreference pref,
                                     gpointer       data);
 
-/**
- * Prints log messages. If Metacity was compiled with backtrace support,
- * also prints a backtrace (see meta_print_backtrace()).
- *
- * \param log_domain  the domain the error occurred in (we ignore this)
- * \param log_level   the log level so that we can filter out less
- *                    important messages
- * \param message     the message to log
- * \param user_data   arbitrary data (we ignore this)
- */
-static void
-log_handler (const gchar   *log_domain,
-             GLogLevelFlags log_level,
-             const gchar   *message,
-             gpointer       user_data)
-{
-  meta_warning ("Log level %d: %s\n", log_level, message);
-  meta_print_backtrace ();
-}
-
 /**
  * Prints the version notice. This is shown when Metacity is called
  * with the --version switch.
@@ -168,11 +148,6 @@ meta_print_compilation_info (void)
 #else
   meta_verbose ("Compiled without startup notification\n");
 #endif
-#ifdef HAVE_COMPOSITE_EXTENSIONS
-  meta_verbose ("Compiled with composite extensions\n");
-#else
-  meta_verbose ("Compiled without composite extensions\n");
-#endif
 }
 
 /**
@@ -225,13 +200,6 @@ typedef struct
   gboolean no_force_fullscreen;
 } MetaArguments;
 
-#ifdef HAVE_COMPOSITE_EXTENSIONS
-#define COMPOSITE_OPTS_FLAGS 0
-#else /* HAVE_COMPOSITE_EXTENSIONS */
-/* No compositor, so don't show the arguments in --help */
-#define COMPOSITE_OPTS_FLAGS G_OPTION_FLAG_HIDDEN
-#endif /* HAVE_COMPOSITE_EXTENSIONS */
-
 /**
  * Parses argc and argv and returns the
  * arguments that Metacity understands in meta_args.
@@ -293,19 +261,19 @@ meta_parse_options (int *argc, char ***argv,
       NULL
     },
     {
-      "composite", 'c', COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
+      "composite", 'c', G_OPTION_ARG_NONE, G_OPTION_ARG_NONE,
       &my_args.composite,
       N_("Turn compositing on"),
       NULL
     },
     {
-      "no-composite", 0, COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
+      "no-composite", 0, G_OPTION_ARG_NONE, G_OPTION_ARG_NONE,
       &my_args.no_composite,
       N_("Turn compositing off"),
       NULL
     },
     {
-      "no-force-fullscreen", 0, COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
+      "no-force-fullscreen", 0, G_OPTION_ARG_NONE, G_OPTION_ARG_NONE,
       &my_args.no_force_fullscreen,
       N_("Don't make fullscreen windows that are maximized and have no decorations"),
       NULL
@@ -397,11 +365,6 @@ main (int argc, char **argv)
   struct sigaction act;
   sigset_t empty_mask;
   MetaArguments meta_args;
-  const gchar *log_domains[] = {
-    NULL, G_LOG_DOMAIN, "Gtk", "Gdk", "GLib",
-    "Pango", "GLib-GObject", "GThread"
-  };
-  guint i;
   GIOChannel *channel;
 
   if (setlocale (LC_ALL, "") == NULL)
@@ -471,61 +434,11 @@ main (int argc, char **argv)
 
   meta_ui_init (&argc, &argv);
 
-  /* must be after UI init so we can override GDK handlers */
-  meta_errors_init ();
-
   /* Load prefs */
   meta_prefs_init ();
   meta_prefs_add_listener (prefs_changed_callback, NULL);
 
-
-#if 1
-
-  for (i=0; i<G_N_ELEMENTS(log_domains); i++)
-    g_log_set_handler (log_domains[i],
-                       G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
-                       log_handler, NULL);
-
-#endif
-
-  if (g_getenv ("METACITY_G_FATAL_WARNINGS") != NULL)
-    g_log_set_always_fatal (G_LOG_LEVEL_MASK);
-
-  meta_ui_set_current_theme (meta_prefs_get_theme (), FALSE);
-
-  /* Try to find some theme that'll work if the theme preference
-   * doesn't exist.  First try Simple (the default theme) then just
-   * try anything in the themes directory.
-   */
-  if (!meta_ui_have_a_theme ())
-    meta_ui_set_current_theme ("Simple", FALSE);
-
-  if (!meta_ui_have_a_theme ())
-    {
-      const char *dir_entry = NULL;
-      GError *err = NULL;
-      GDir   *themes_dir = NULL;
-
-      if (!(themes_dir = g_dir_open (METACITY_DATADIR"/themes", 0, &err)))
-        {
-          meta_fatal (_("Failed to scan themes directory: %s\n"), err->message);
-          g_error_free (err);
-        }
-      else
-        {
-          while (((dir_entry = g_dir_read_name (themes_dir)) != NULL) &&
-                 (!meta_ui_have_a_theme ()))
-            {
-              meta_ui_set_current_theme (dir_entry, FALSE);
-            }
-
-          g_dir_close (themes_dir);
-        }
-    }
-
-  if (!meta_ui_have_a_theme ())
-    meta_fatal (_("Could not find a theme! Be sure %s exists and contains the usual themes.\n"),
-                METACITY_DATADIR"/themes");
+  meta_ui_reload_theme ();
 
   /* Connect to SM as late as possible - but before managing display,
    * or we might try to manage a window before we have the session
@@ -639,9 +552,10 @@ prefs_changed_callback (MetaPreference pref,
 {
   switch (pref)
     {
-    case META_PREF_THEME:
+    case META_PREF_THEME_NAME:
+    case META_PREF_THEME_TYPE:
     case META_PREF_COMPOSITING_MANAGER:
-      meta_ui_set_current_theme (meta_prefs_get_theme (), TRUE);
+      meta_ui_reload_theme ();
       meta_display_retheme_all ();
       break;
 
