@@ -384,11 +384,11 @@ meta_screen_new (MetaDisplay *display,
         }
 
       /* We want to find out when the current selection owner dies */
-      meta_error_trap_push_with_return (display);
+      meta_error_trap_push (display);
       attrs.event_mask = StructureNotifyMask;
       XChangeWindowAttributes (xdisplay,
                                current_wm_sn_owner, CWEventMask, &attrs);
-      if (meta_error_trap_pop_with_return (display, FALSE) != Success)
+      if (meta_error_trap_pop_with_return (display) != Success)
         current_wm_sn_owner = None; /* don't wait for it to die later on */
     }
 
@@ -443,7 +443,7 @@ meta_screen_new (MetaDisplay *display,
     }
 
   /* select our root window events */
-  meta_error_trap_push_with_return (display);
+  meta_error_trap_push (display);
 
   /* We need to or with the existing event mask since
    * gtk+ may be interested in other events.
@@ -456,11 +456,9 @@ meta_screen_new (MetaDisplay *display,
                 LeaveWindowMask | EnterWindowMask |
                 KeyPressMask | KeyReleaseMask |
                 FocusChangeMask | StructureNotifyMask |
-#ifdef HAVE_COMPOSITE_EXTENSIONS
                 ExposureMask |
-#endif
-		attr.your_event_mask);
-  if (meta_error_trap_pop_with_return (display, FALSE) != Success)
+                attr.your_event_mask);
+  if (meta_error_trap_pop_with_return (display) != Success)
     {
       meta_warning (_("Screen %d on display \"%s\" already has a window manager\n"),
                     number, display->name);
@@ -490,11 +488,10 @@ meta_screen_new (MetaDisplay *display,
   screen->wm_sn_atom = wm_sn_atom;
   screen->wm_sn_timestamp = manager_timestamp;
 
-#ifdef HAVE_COMPOSITE_EXTENSIONS
   screen->wm_cm_selection_window = meta_create_offscreen_window (xdisplay,
                                                                  xroot,
                                                                  NoEventMask);
-#endif
+
   screen->work_area_idle = 0;
 
   screen->active_workspace = NULL;
@@ -672,9 +669,9 @@ meta_screen_free (MetaScreen *screen,
 
   meta_stack_free (screen->stack);
 
-  meta_error_trap_push_with_return (screen->display);
+  meta_error_trap_push (screen->display);
   XSelectInput (screen->display->xdisplay, screen->xroot, 0);
-  if (meta_error_trap_pop_with_return (screen->display, FALSE) != Success)
+  if (meta_error_trap_pop_with_return (screen->display) != Success)
     meta_warning (_("Could not release screen %d on display \"%s\"\n"),
                   screen->number, screen->display->name);
 
@@ -738,12 +735,12 @@ list_windows (MetaScreen *screen)
     {
       WindowInfo *info = g_new0 (WindowInfo, 1);
 
-      meta_error_trap_push_with_return (screen->display);
+      meta_error_trap_push (screen->display);
 
       XGetWindowAttributes (screen->display->xdisplay,
                             children[i], &info->attrs);
 
-      if (meta_error_trap_pop_with_return (screen->display, TRUE))
+      if (meta_error_trap_pop_with_return (screen->display))
 	{
           meta_verbose ("Failed to get attributes for window 0x%lx\n",
                         children[i]);
@@ -783,9 +780,7 @@ meta_screen_manage_all_windows (MetaScreen *screen)
                                            &info->attrs);
       if (info->xwindow == screen->no_focus_window ||
           info->xwindow == screen->flash_window ||
-#ifdef HAVE_COMPOSITE_EXTENSIONS
           info->xwindow == screen->wm_cm_selection_window ||
-#endif
           info->xwindow == screen->wm_sn_selection_window) {
         meta_verbose ("Not managing our own windows\n");
         continue;
@@ -806,7 +801,6 @@ meta_screen_manage_all_windows (MetaScreen *screen)
 void
 meta_screen_composite_all_windows (MetaScreen *screen)
 {
-#ifdef HAVE_COMPOSITE_EXTENSIONS
   MetaDisplay *display;
   GList *windows, *list;
 
@@ -840,7 +834,6 @@ meta_screen_composite_all_windows (MetaScreen *screen)
 
   g_list_foreach (windows, (GFunc)g_free, NULL);
   g_list_free (windows);
-#endif
 }
 
 MetaScreen*
@@ -1048,7 +1041,7 @@ set_number_of_spaces_hint (MetaScreen *screen,
                    screen->display->atom__NET_NUMBER_OF_DESKTOPS,
                    XA_CARDINAL,
                    32, PropModeReplace, (guchar*) data, 1);
-  meta_error_trap_pop (screen->display, FALSE);
+  meta_error_trap_pop (screen->display);
 }
 
 static void
@@ -1069,7 +1062,7 @@ set_desktop_geometry_hint (MetaScreen *screen)
                    screen->display->atom__NET_DESKTOP_GEOMETRY,
                    XA_CARDINAL,
                    32, PropModeReplace, (guchar*) data, 2);
-  meta_error_trap_pop (screen->display, FALSE);
+  meta_error_trap_pop (screen->display);
 }
 
 static void
@@ -1093,7 +1086,7 @@ set_desktop_viewport_hint (MetaScreen *screen)
                    screen->display->atom__NET_DESKTOP_VIEWPORT,
                    XA_CARDINAL,
                    32, PropModeReplace, (guchar*) data, 2);
-  meta_error_trap_pop (screen->display, FALSE);
+  meta_error_trap_pop (screen->display);
 }
 
 static void
@@ -1234,7 +1227,7 @@ get_window_pixbuf (MetaWindow *window,
   pixbuf = meta_ui_get_pixbuf_from_surface (surface);
   cairo_surface_destroy (surface);
 
-  if (meta_error_trap_pop_with_return (NULL, FALSE) != Success)
+  if (meta_error_trap_pop_with_return (NULL) != Success)
     g_clear_object (&pixbuf);
 
   if (pixbuf == NULL) 
@@ -1567,7 +1560,7 @@ meta_screen_get_mouse_window (MetaScreen  *screen,
                  &win_x_return,
                  &win_y_return,
                  &mask_return);
-  meta_error_trap_pop (screen->display, TRUE);
+  meta_error_trap_pop (screen->display);
 
   window = meta_stack_get_default_focus_window_at_point (screen->stack,
                                                          screen->active_workspace,
@@ -1934,7 +1927,7 @@ set_workspace_names (MetaScreen *screen)
 		   screen->display->atom_UTF8_STRING,
                    8, PropModeReplace,
 		   (unsigned char *)flattened->str, flattened->len);
-  meta_error_trap_pop (screen->display, FALSE);
+  meta_error_trap_pop (screen->display);
 
   g_string_free (flattened, TRUE);
 }
@@ -2038,7 +2031,7 @@ set_work_area_hint (MetaScreen *screen)
 		   XA_CARDINAL, 32, PropModeReplace,
 		   (guchar*) data, num_workspaces*4);
   g_free (data);
-  meta_error_trap_pop (screen->display, FALSE);
+  meta_error_trap_pop (screen->display);
 }
 
 static gboolean
@@ -2411,7 +2404,7 @@ meta_screen_update_showing_desktop_hint (MetaScreen *screen)
                    screen->display->atom__NET_SHOWING_DESKTOP,
                    XA_CARDINAL,
                    32, PropModeReplace, (guchar*) data, 1);
-  meta_error_trap_pop (screen->display, FALSE);
+  meta_error_trap_pop (screen->display);
 }
 
 static void
@@ -2889,7 +2882,6 @@ meta_screen_set_compositor_data (MetaScreen *screen,
   screen->compositor_data = compositor;
 }
 
-#ifdef HAVE_COMPOSITE_EXTENSIONS
 void
 meta_screen_set_cm_selection (MetaScreen *screen)
 {
@@ -2917,4 +2909,3 @@ meta_screen_unset_cm_selection (MetaScreen *screen)
   XSetSelectionOwner (screen->display->xdisplay, a,
                       None, screen->wm_cm_timestamp);
 }
-#endif /* HAVE_COMPOSITE_EXTENSIONS */
